package provide scanvas 1.0

##  scanvas.tcl
##
##	Scrolled-canvas : an extension to the canvas widget.
##      Horizontal and vertical scrollbars are provided by default.
##
##  Copyright (c) 2003 <Irrational Numbers> : <aburatti@libero.it> 
##
##  NOTE: package "snit" (v0.91) is required.
##   It is freely downloadable from the Web:
##       http://www.wjduquette.com/snit
##
##  This program is free software; you can redistibute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation.
##
##  See the file "license" for information on usage and
##  redistribution of this program, and for a disclaimer of all warranties.
##

package require snit 0.91

#
# How to use scrolledcanvas:
#   Read "scanvas.txt" for detailed info.
#   Sample code in provided in "demo*.tcl".
#

option add *Scanvas.vscrollside right
option add *Scanvas.hscrollside bottom

snit::widget scanvas {
    widgetclass Scanvas

    expose hscroll
    expose vscroll
    expose hull as frame

    option -vscrollside 
    option -hscrollside

    delegate option * to cvs
    delegate method * to cvs

    constructor {args} {
       install hscroll using scrollbar $win.hscroll -orient horiz -command "$win.cvs xview"
       install vscroll using scrollbar $win.vscroll -command "$win.cvs yview"

       install cvs using canvas $win.cvs  \
	  -xscrollcommand "$win.hscroll set" \
	  -yscrollcommand "$win.vscroll set"

        # 3 x 3 grid ; 
	#  the central cell (1,1) is for the canvas widget.
	#  +-----+-----+----+  
	#  |     | h1  |    |
	#  +-----+-----+----+  
	#  | v1  | cvs | v2 |
	#  +-----+-----+----+  
	#  |     | h2  |    |
	#  +-----+-----+----+  
	# Cells h1 or h2 are for horizontal scrollbar (alternatively)
	# Cells v1 or v2 are for vertical   scrollbar (alternatively)
	#  Note that scrollbars may be hidden.
       grid rowconfig    $win 1 -weight 1 -minsize 0
       grid columnconfig $win 1 -weight 1 -minsize 0

       grid $win.cvs      -padx 1 -pady 1 -row 1 -column 1  -sticky news
       $win configure -vscrollside right
       $win configure -hscrollside bottom

       # internal canvas should inherit the frame bindings
       bindtags $win.cvs [list $win.cvs $win Canvas . all ]

       $self configurelist $args
    }


    onconfigure -vscrollside {value} {
         switch $value {
             right  { set column 2 }
             left   { set column 0 }
             none   { ; }
             default { return }
         }
         grid forget $win.vscroll
         set options(-vscrollside) $value

         if { $value != "none" } {
            grid $win.vscroll  -padx 1 -pady 1 -row 1 -column $column -sticky ns
         }
    }

    onconfigure -hscrollside {value} {
         switch $value {
             top    { set row 0 }
             bottom { set row 2 }
             none   { ; }
             default { return }
         }
         grid forget $win.hscroll
         set options(-hscrollside) $value

         if { $value != "none" } {
            grid $win.hscroll  -padx 1 -pady 1 -row $row -column 1 -sticky we
         }
    }

}
